@@ -31,7 +31,7 @@ package Sub::Starter;
 # --------------------------------------
 # Pragmatics
 
-require v5.8.0;
+require 5.008;
 
 use strict;
 use warnings;
@@ -40,7 +40,7 @@ use utf8;  # Convert all UTF-8 to Perl's internal representation.
 
 # --------------------------------------
 # Version
-use version; our $VERSION = qv(v1.0.4);
+use version; our $VERSION = qv(v1.0.5);
 
 # --------------------------------------
 # Modules
@@ -801,7 +801,7 @@ Sub::Starter - Creates a skeletal framework for Perl sub's.
 
 =head1 VERSION
 
-This document refers to Sub::Starter version v1.0.4
+This document refers to Sub::Starter version v1.0.5
 
 =head1 SYNOPSIS
 
